summaryrefslogtreecommitdiff
path: root/xmlsecurity/inc/xmlsecurity/digitalsignaturesdialog.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'xmlsecurity/inc/xmlsecurity/digitalsignaturesdialog.hxx')
-rw-r--r--xmlsecurity/inc/xmlsecurity/digitalsignaturesdialog.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/xmlsecurity/inc/xmlsecurity/digitalsignaturesdialog.hxx b/xmlsecurity/inc/xmlsecurity/digitalsignaturesdialog.hxx
index 4d48aad47555..d40f2ebf4a12 100644
--- a/xmlsecurity/inc/xmlsecurity/digitalsignaturesdialog.hxx
+++ b/xmlsecurity/inc/xmlsecurity/digitalsignaturesdialog.hxx
@@ -132,8 +132,8 @@ public:
sal_Bool bReadOnly, const ::rtl::OUString& sODFVersion, bool bHasDocumentSignature);
~DigitalSignaturesDialog();
- // Initialize the dialog and the security environment, returns TRUE on success
- BOOL Init( const rtl::OUString& rTokenName );
+ // Initialize the dialog and the security environment, returns sal_True on success
+ sal_Bool Init( const rtl::OUString& rTokenName );
// Set the storage which should be signed or verified
void SetStorage( const cssu::Reference < css::embed::XStorage >& rxStore );